/*
 * riscv-bldc.h
 *
 *  Created on: 28.07.2018
 *      Author: eyck
 */

#ifndef RISCV_BLDC_H_
#define RISCV_BLDC_H_

#include <cstdint>

extern uint32_t pwm;
extern uint32_t DRIVE_PORT;

enum {
    UL=1,      //! Port pin connected to phase U, low side enable switch.
    UH=0,      //! Port pin connected to phase U, high side enable switch.
    VL=11,     //! Port pin connected to phase V, low side enable switch.
    VH=10,     //! Port pin connected to phase V, high side enable switch.
    WL=19,     //! Port pin connected to phase W, low side enable switch.
    WH=20,     //! Port pin connected to phase W, high side enable switch.
    CW=0,      //! Clockwise rotation flag.
    CCW=1,     //! Counterclockwise rotation flag.
    SENSU_P=0, //! Phase U voltage to sense
    SENSV_P=1, //! Phase V voltage to sense
    SENSW_P=2, //! Phase W voltage to sense
    SENSU_N=4, //! Phase U voltage to sense
    SENSV_N=5, //! Phase V voltage to sense
    SENSW_N=6, //! Phase W voltage to sense
    DRIVE_MASK=(1<<UL)|(1<<UH)| (1<<VL)|(1<<VH)| (1<<WL)|(1<<WH)
};

//! Startup delays are given in microseconds times STARTUP_DELAY_MULTIPLIER.
const auto STARTUP_DELAY_MULTIPLIER=1000;
/*!
 *  Number of milliseconds to lock rotor in first commutation step before
 *  the timed startup sequence is initiated.
 */
const auto STARTUP_LOCK_DELAY=200;

extern "C" void handle_m_ext_interrupt();
extern "C" void handle_m_time_interrupt();

#endif /* RISCV_BLDC_H_ */
